<?php

/**
 * The template for displaying the footer
 *
 * Contains the closing of the #content div and all content after.
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Simplify_365
 */

?>

<!-- Footer Start -->
<footer class="site-footer">
	<div class="container">
		<div class="footer-bottom-box">
			<div class="row align-items-center">
				<div class="main-footer">
					<div class="row">
						<div class="col-lg-4">
							<div class="site-details-wrapper">
								<div class="site-deails">
									<div class="site-branding">
										<?php
										the_custom_logo();
										?>
									</div>
									<?php
									$footer_content = get_field('footer_content', 'option');
									echo wp_kses_post($footer_content);
									?>
								</div>

								<div class="social-media">
									<ul>
										<?php
										$facebook_url = get_field('facebook_url', 'option');
										if (!empty($facebook_url)) {
										?>
											<li>
												<a href="<?php echo esc_url($facebook_url['url']); ?>" target="_blank"
													title="<?php echo esc_attr($facebook_url['title']); ?>">
													<i class="fab fa-facebook"></i>
												</a>
											</li>
										<?php
										}
										$youtube_url = get_field('youtube_url', 'option');
										if (!empty($youtube_url)) { ?>
											<li>
												<a href="<?php echo esc_url($youtube_url['url']); ?>" target="_blank"
													title="<?php echo esc_attr($youtube_url['title']); ?>">
													<i class="fab fa-youtube"></i>
												</a>
											</li>
										<?php
										}
										$linkedin_url = get_field('linkedin_url', 'option');
										if (!empty($linkedin_url)) { ?>
											<li>
												<a href="<?php echo esc_url($linkedin_url['url']); ?>" target="_blank"
													title="<?php echo esc_attr($linkedin_url['title']); ?>">
													<i class="fab fa-linkedin"></i>
												</a>
											</li>
										<?php
										} ?>
									</ul>
								</div>
							</div>
						</div>
						<div class="col-lg-4">
							<div class="footer-links-block">
								<div class="footer-links">
									<?php
									$about_us_title = get_field('about_us_title', 'option');
									echo (!empty($about_us_title)) ? '<h6 class="h6-title">' . esc_html($about_us_title) . '</h6>' : ''; ?>

									<?php
									wp_nav_menu(
										array(
											'theme_location' => 'footer-menu',
										)
									);
									?>
								</div>
								<div class="footer-links">
									<?php
									$privacy_title = get_field('privacy_title', 'option');
									echo (!empty($privacy_title)) ? '<h6 class="h6-title">' . esc_html($privacy_title) . '</h6>' : ''; ?>
									<?php
									wp_nav_menu(
										array(
											'theme_location' => 'footer-menu-privacy',
										)
									);
									?>
								</div>
							</div>
						</div>
						<?php
						$newsletter_title = get_field('newsletter_title', 'option');
						$newsletter_form = get_field('newsletter_form', 'option');
						$newsletter_description = get_field('newsletter_description', 'option');
						$phone_number = get_field('phone_number', 'option');
						$email_url = get_field('email_url', 'option');
						?>
						<div class="col-lg-4">
							<div class="contact-block">
								<?php
								echo (!empty($newsletter_title)) ? '<h6 class="h6-title">' . esc_html($newsletter_title) . '</h6>' : '';

								if (!empty($newsletter_form)) { ?>
									<div class="signup-form">
										<?php
										echo do_shortcode($newsletter_form);
										// echo do_shortcode('[ctct form="' . $newsletter_form->ID . '" show_title="false"]');
										?>
									</div>
								<?php
								}
								if (!empty($newsletter_description)) {
								?>
									<div class="body-s">
										<p><?php echo wp_kses_post($newsletter_description); ?></p>
									</div>
								<?php
								}
								?>
								<div class="contact-wrapper">
									<?php
									if (!empty($phone_number)) {
									?>
										<h4 class="h4-title">
											<a href="<?php echo esc_url($phone_number['url']); ?>"
												title="<?php echo esc_attr($phone_number['title']); ?>"
												class="call-link">
												<span class="callus">
													<?php echo esc_html($phone_number['title']); ?>
												</span>
											</a>
										</h4>
									<?php
									}
									if (!empty($email_url)) {
									?>
										<a href="mailto:<?php echo esc_attr($email_url); ?>"
											title="<?php echo esc_attr($email_url); ?>"><?php echo esc_html($email_url); ?></a>
									<?php
									} ?>
								</div>
							</div>
						</div>
					</div>
					<?php
					if (have_rows('locations_list', 'option')) {
					?>
						<div class="contact-location">
							<div class="row">
								<?php
								while (have_rows('locations_list', 'option')) {
									the_row();

									$locations = get_sub_field('locations');
									if (!empty($locations)) {
								?>
										<div class="col-lg-4">
											<div class="location-wrapper">
												<img src="<?php echo home_url(); ?>/wp-content/uploads/2024/10/location-icon.svg"
													alt="Location" width="12" height="14">
												<div class="location-info">
													<?php echo wp_kses_post($locations); ?>
												</div>
											</div>
										</div>
								<?php
									}
								} ?>
							</div>
						</div>
					<?php
					} ?>
				</div>
				<div class="col-12">
					<div class="footer-bottom-text">
						<?php
						$site_name = get_bloginfo('site_name');
						$bottom_footer_content = get_field('bottom_footer_content', 'option');
						?>
						<div class="copy-right body-s">
							<p>© <?php echo date('Y ') . $site_name . '. ' . $bottom_footer_content; ?></p>
						</div>
						<?php
						$view_all_service_button_text = get_field("view_all_service_button_text", "option");

						if (is_page_template('template-seo.php') || is_archive() || is_author() || is_category() || is_home() || is_single() || is_tag()) { ?>
							<div class="row">
								<div class="col-lg-12">
									<div class="footer-last">
										<?php
										if (!empty($view_all_service_button_text)) { ?>
											<span class="text view_services_text" id="view_all_services"
												title="<?php echo esc_attr($view_all_service_button_text); ?>"><?php echo esc_html($view_all_service_button_text); ?></span>
										<?php } ?>
										<div class="all-services">
											<?php
											wp_nav_menu(array('theme_location' => 'seo-menu'));
											?>
										</div>
									</div>
								</div>
							</div>
						<?php } ?>
						<div class="footer-bottom-link">
							<?php
							wp_nav_menu(array(
								'theme_location' => 'policy-menu',
							));
							?>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
</footer>
<!-- Footer End -->

</div><!-- #page -->
<?php wp_footer(); ?>
<?php

$front_page_id = get_option('page_on_front');

$home_banner_popup_form_title = get_field('home_banner_popup_form_title', $front_page_id);
$home_banner_popup_form = get_field('home_banner_popup_form', $front_page_id);

if (!empty($home_banner_popup_form)) {
?>
	<div class="modal common-popup fade" id="download_newsletter">
		<div class="modal-dialog">
			<div class="modal-content">
				<div class="popup-title">
					<?php echo (!empty($home_banner_popup_form_title)) ? '<h2 class="h2-title">' . esc_html($home_banner_popup_form_title) . '</h2>' : ''; ?>
					<button type="button" class="close close-popup" data-bs-dismiss="modal"><i class="fas fa-times"
							aria-hidden="true"></i></button>
				</div>
				<div class="common-popup-overflow">
					<div class="common-popup-text" data-bs-simplebar>
						<div class="contact-form modal-form contact-form-section">
							<?php
							echo do_shortcode($home_banner_popup_form);
							?>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
<?php
}

if (is_page(191)) { ?>
	<script>
		// Initialize the map
		function initMap() {
			var map;
			var infoWindows = [];
			var markers = [];
			var currentInfoWindow = null;
			var currentMarker = null;
			// var image = "<?php the_field("google_map_marker_icon", "option"); ?>";
			// var highlightedIcon = "<?php the_field("google_map_hover_icon", "option"); ?>";

			map = new google.maps.Map(document.getElementById('map-wrapper'), {
				zoom: 15,
				center: new google.maps.LatLng(34.4127007, -118.5099082),
				mapTypeId: google.maps.MapTypeId.ROADMAP
			});

			var stores = document.getElementsByClassName('cta-link');
			for (var i = 0; i < stores.length; i++) {
				var store = stores[i];
				var lat = parseFloat(store.getAttribute('data-lat'));
				var lng = parseFloat(store.getAttribute('data-lng'));
				var imageUrl = store.getAttribute('data-image');
				var title = store.getAttribute('data-title');

				// Create marker
				var marker = new google.maps.Marker({
					position: {
						lat: lat,
						lng: lng
					},
					map: map,
					title: title,
					// icon: image,
				});

				// Create info window content
				// var content = '<div class="map-img-custom"> <img src="' + imageUrl + '" alt="Location Thumbnail"> <p>' + title + '</p> </div>';

				// Create info window
				// var infoWindow = new google.maps.InfoWindow({
				//     content: content
				// });

				// Push info window and marker to arrays
				// infoWindows.push(infoWindow);
				markers.push(marker);

				// Add click event listener to show corresponding info window
				marker.addListener('click', function() {
					if (currentInfoWindow) {
						currentInfoWindow.close();
						// currentMarker.setIcon(image); // Reset marker icon
					}
					var index = markers.indexOf(this);
					infoWindows[index].open(map, this);
					// this.setIcon(highlightedIcon);
					currentInfoWindow = infoWindows[index];
					currentMarker = this;
				});

				// Add click event listener to show corresponding marker on map when store is clicked
				store.addEventListener('click', function(e) {
					e.preventDefault();
					var index = Array.prototype.indexOf.call(stores, this);
					map.panTo(markers[index].getPosition());
					map.setZoom(15); // Optionally, you can zoom in when a store is clicked
					if (currentInfoWindow) {
						currentInfoWindow.close();
						// currentMarker.setIcon(image); // Reset marker icon
					}
					infoWindows[index].open(map, markers[index]);
					// markers[index].setIcon(highlightedIcon)
					currentInfoWindow = infoWindows[index];
					currentMarker = markers[index];
				});

				// Add closeclick event listener to reset marker icon when info window is closed
				// infoWindow.addListener('closeclick', function() {
				//     if (currentMarker) {
				//         // currentMarker.setIcon(image); // Reset marker icon
				//     }
				// });
			}
		}
		// Call initMap when page is loaded
		initMap();
	</script>
<?php } ?>
</body>

</html>