<?php

/**
 * Simplify 365 functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Simplify_365
 */

if (!defined('_S_VERSION')) {
	// Replace the version number of the theme on each release.
	define('_S_VERSION', '1.0.0');
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function simplify_365_setup()
{
	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Simplify 365, use a find and replace
	 * to change 'simplify-365' to the name of your theme in all the template files.
	 */
	load_theme_textdomain('simplify-365', get_template_directory() . '/languages');

	// Add default posts and comments RSS feed links to head.
	add_theme_support('automatic-feed-links');

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support('title-tag');

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
	 */
	add_theme_support('post-thumbnails');

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(
		array(
			'primary-menu' => esc_html__('Primary Menu', 'simplify-365'),
			'footer-menu-about-us' => esc_html__('Footer Menu About us', 'simplify-365'),
			'footer-menu-privacy' => esc_html__('Footer Menu Privacy', 'simplify-365'),
			'seo-menu' => esc_html__('Seo Menu', 'simplify-365'),
			'policy-menu' => esc_html__('Policy Menu', 'simplify-365'),
			'navigation-menu' => esc_html__('Navigation Menu', 'simplify-365'),
		)
	);

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support(
		'html5',
		array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
		)
	);

	// Set up the WordPress core custom background feature.
	add_theme_support(
		'custom-background',
		apply_filters(
			'simplify_365_custom_background_args',
			array(
				'default-color' => 'ffffff',
				'default-image' => '',
			)
		)
	);

	// Add theme support for selective refresh for widgets.
	add_theme_support('customize-selective-refresh-widgets');

	/**
	 * Add support for core custom logo.
	 *
	 * @link https://codex.wordpress.org/Theme_Logo
	 */
	add_theme_support(
		'custom-logo',
		array(
			'height' => 250,
			'width' => 250,
			'flex-width' => true,
			'flex-height' => true,
		)
	);
}
add_action('after_setup_theme', 'simplify_365_setup');

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function simplify_365_content_width()
{
	$GLOBALS['content_width'] = apply_filters('simplify_365_content_width', 640);
}
add_action('after_setup_theme', 'simplify_365_content_width', 0);

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function simplify_365_widgets_init()
{
	register_sidebar(
		array(
			'name' => esc_html__('Sidebar', 'simplify-365'),
			'id' => 'sidebar-1',
			'description' => esc_html__('Add widgets here.', 'simplify-365'),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget' => '</section>',
			'before_title' => '<h2 class="widget-title">',
			'after_title' => '</h2>',
		)
	);
}
add_action('widgets_init', 'simplify_365_widgets_init');

/**
 * Enqueue scripts and styles.
 */
function simplify_365_scripts()
{
	// $templates = array('template-our-location.php');

	// if(is_front_page() || is_page_template($templates)){
	// 	wp_register_script('simplify-365-googlemaps', 'https://maps.googleapis.com/maps/api/js?key='.get_field("google_map_api", "option").'&loading=async', array(), '', true);
	// 	wp_enqueue_script('simplify-365-googlemaps');
	// 	wp_enqueue_script('simplify-365-custom-map-js', get_template_directory_uri() . '/assets/js/custom-map.js', array(), rand(1000,100000), true);
	// }

	if (is_page(191)) {
		wp_register_script('simplify-365-googlemaps', 'https://maps.googleapis.com/maps/api/js?key=' . get_field("google_map_api_key", "option"), array(), '', true);
		wp_enqueue_script('simplify-365-googlemaps');
	}

	wp_style_add_data('simplify-365-style', 'rtl', 'replace');

	wp_enqueue_style('simplify-365-layout-min-css', get_template_directory_uri() . '/assets/css/layout.min.css', array(), '20151215');
	wp_enqueue_style('simplify-365-jquery-fancybox-min-css', get_template_directory_uri() . '/assets/css/jquery.fancybox.min.css', array(), '20151215');

	wp_enqueue_script('jquery');
	wp_enqueue_style('simplify-365-swiper.min-css', get_template_directory_uri() . '/assets/css/swiper.min.css', array(), '20151215');

	wp_enqueue_style('simplify-365-style', get_stylesheet_uri(), array(), _S_VERSION);

	wp_enqueue_script('scrolltrigger-js', 'https://unpkg.com/gsap@3/dist/ScrollTrigger.min.js', array(), '20151215', true);
	wp_enqueue_script('gsap-js', 'https://unpkg.com/gsap@3/dist/gsap.min.js', array(), '20151215', true);

	wp_enqueue_script('simplify-365-layout-js', get_template_directory_uri() . '/assets/js/layout.js', array(), '20151215', true);
	// wp_enqueue_script('simplify-365-slick-min-js', get_template_directory_uri() . '/assets/js/slick.min.js', array(), '20151215', true);
	wp_enqueue_script('simplify-365-swiper.min-js', get_template_directory_uri() . '/assets/js/swiper.min.js', array(), '20151215', true);
	wp_enqueue_script('simplify-365-simplebar-js', get_template_directory_uri() . '/assets/js/simplebar.js', array(), '20151215', true);
	wp_enqueue_script('simplify-365-popper-min-js', get_template_directory_uri() . '/assets/js/popper.min.js', array(), '20151215', true);
	wp_enqueue_script('simplify-365-bootstrap.bundle.min-js', get_template_directory_uri() . '/assets/js/bootstrap.bundle.min.js', array(), '20151215', true);
	wp_enqueue_script('simplify-365-jquery-fancybox-min-js', get_template_directory_uri() . '/assets/js/jquery.fancybox.min.js', array(), '20151215', true);
	wp_enqueue_script('simplify-365-custom-js', get_template_directory_uri() . '/assets/js/custom.js', array(), '20151215', true);

	wp_localize_script('simplify-365-custom-js', 'custom_call', ['ajaxurl' => admin_url('admin-ajax.php'), 'homeurl' => home_url()]);
	//wp_register_script('simplify-365-googlemaps', 'https://maps.googleapis.com/maps/api/js?key=' . get_field("google_map_api", "option"), array(), '', true);
	//wp_enqueue_script('simplify-365-googlemaps');

	wp_enqueue_script('simplify-365-navigation', get_template_directory_uri() . '/js/navigation.js', array(), _S_VERSION, true);

	if (is_singular() && comments_open() && get_option('thread_comments')) {
		wp_enqueue_script('comment-reply');
	}

}
add_action('wp_enqueue_scripts', 'simplify_365_scripts');

/**
 * Implement the Custom Header feature. 
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

$front_page_id = get_option("page_on_front");
if ($front_page_id) {
	require get_template_directory() . '/inc/custom-ajax-function.php';
}

/**
 * Load Jetpack compatibility file.
 */
if (defined('JETPACK__VERSION')) {
	require get_template_directory() . '/inc/jetpack.php';
}


// Custom Functions



// Filter the output of the logo to fix Google errors about itemprop logo
add_filter('get_custom_logo', 'change_html_custom_logo');
function change_html_custom_logo()
{
	$custom_logo_id = get_theme_mod('custom_logo');
	$site_name = get_bloginfo('name');
	$html = sprintf(
		'<a href="%1$s" class="custom-logo-link" rel="home" title="' . $site_name . '">%2$s</a>',
		esc_url(home_url('/')),
		wp_get_attachment_image($custom_logo_id, 'full', false, array(
			'class' => 'custom-logo',

		))
	);
	return $html;
}


function play_icon($url)
{

	$parsedUrl = parse_url($url, PHP_URL_QUERY);

	parse_str($parsedUrl, $queryParams);

	$unique_id = $queryParams['si'] ?? null;

	?>

	<a href="<?php echo esc_url($url) ?>" data-fancybox="video-<?php echo esc_attr($unique_id); ?>"
		data-fancybox-group="none" title="Video-<?php echo esc_attr($unique_id); ?>" tabindex="0">
		<div class="play-btn-wp">
			<span class="play-btn"></span>
		</div>
	</a>
	<?php
}


function banner_details($title, $content)
{

	if (!empty($title) || !empty($content)) {

		?>
		<section class="inner-banner">
			<div class="container">
				<div class="inner-banner-content-wp">
					<div class="row justify-content-center">
						<div class="col-lg-10 col-xl-8">
							<div class="inner-banner-content">
								<?php
								if (!empty($title)) {
									?>
									<h1 class="h1-title wow fadeup-animation" data-wow-duration="0.8s" data-wow-delay="0.2s">
										<?php echo $title; ?>
									</h1>
									<?php
								}
								if (!empty($content)) {
									?>
									<div class="body-l wow fadeup-animation" data-wow-duration="0.8s" data-wow-delay="0.3s">

										<?php echo $content; ?>
									</div>
									<?php
								} ?>
							</div>
						</div>
					</div>
				</div>
			</div>
		</section>
		<?php
	}
}


function shorten_post_content($content)
{
	$limit = 200;
	if (strlen($content) > $limit) {

		$short_content = substr($content, 0, $limit);

		$short_content .= '...';
		return $short_content;
	}

	return $content;
}
function post_case_studies_content($content)
{
	$limit = 300;
	if (strlen($content) > $limit) {

		$short_content = substr($content, 0, $limit);

		$short_content .= '...';
		return $short_content;
	}

	return $content;
}

// register home_url shortcode
function home_url_callback()
{
	return home_url();
}
add_shortcode('home_url', 'home_url_callback');


//add_action('wp_footer', 'add_custom_script');

//cta service section
function cta_service_section($title, $content)
{
	?>
	<section class="book-a-consultation-sec">
		<div class="container">
			<div class="book-a-consultation-box-wp">
				<?php
				$background_shape = get_field('background_shape', 'option');

				if (!empty($background_shape)) {
					?>
					<div class="book-a-consultation-shape">
						<span class="mask-img"
							style="-webkit-mask-image: url('<?php echo esc_url($background_shape); ?>');"></span>
					</div>
					<?php
				} ?>
				<div class="row">
					<div class="col-lg-9 wow left-animation" data-wow-duration="0.8s" data-wow-delay="0.2s">
						<div class="book-a-consultation-content white-text">
							<?php
							if (!empty($title)) {
								?>
								<div class="sec-title">
									<h2 class="h2-title"><?php echo wp_kses($title, array('span' => array())); ?></h2>
								</div>
								<?php
							}
							if (!empty($content)) {
								?>
								<div class="book-a-consultation-description-text">
									<?php echo wp_kses_post($content); ?>
								</div>
								<?php
							} ?>
						</div>
					</div>
					<?php
					$consultation_button_text = get_field('consultation_button_text', 'option');
					$consultation_button_url = get_field('consultation_button_url', 'option');

					if (!empty($consultation_button_text) && !empty($consultation_button_url)) {
						?>
						<div class="col-lg-3 align-self-center wow right-animation" data-wow-duration="0.8s"
							data-wow-delay="0.2s">
							<div class="book-a-consultation-content-btn">
								<a href="<?php echo esc_url($consultation_button_url); ?>" class="sec-btn white-btn sm-btn"
									title="<?php echo esc_attr($consultation_button_text); ?>"><?php echo esc_html($consultation_button_text); ?></a>
							</div>
						</div>
						<?php
					} ?>
				</div>
			</div>
		</div>
	</section>
	<?php
}


function common_struture_posts()
{

	$categories = get_the_category();
	$cat_list = [];
	if (!empty($categories)) {
		foreach ($categories as $category) {
			$cat_list[] = $category->name;
		}
	}

	$default_image = home_url() . '/wp-content/uploads/2024/10/placeholder-image.png';
	$thumbnail_image = !empty(get_the_post_thumbnail_url()) ? esc_url(get_the_post_thumbnail_url()) : $default_image;
	?>
	<div class="col-lg-4 post-item" data-category="<?php echo implode(' ', wp_list_pluck($categories, 'term_id')); ?>">
		<div class="info-card">
			<div class="card-img">
				<a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>" class="back-img"
					style="background-image: url('<?php echo $thumbnail_image; ?>')"></a>
				<?php
				$video_url = get_field('video_url');
				if (!empty($video_url)) {
					play_icon($video_url);
				} ?>
			</div>

			<div class="card-content">
				<div class="body-s">
					<p class="card-info-tag"><?php echo implode(', ', $cat_list); ?></p>
				</div>
				<h4 class="h4-title">
					<a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>">
						<?php the_title(); ?>
					</a>
				</h4>
				<?php
				if (!empty(get_the_content())) {
					?>
					<p><?php echo wp_html_excerpt(get_the_content(), 200); ?></p>
				<?php
				} ?>

			</div>

		</div>

	</div>
	<?php
}

//load more post 

function load_more_case_studies()
{
	$paged = $_POST['data']['page'];
	$cat_id = $_POST['data']['category'];
	$search_value = isset($_POST['data']['search_data']) ? sanitize_text_field($_POST['data']['search_data']) : '';
	// echo '<pre>'; print_r( $paged ); echo '</pre>';
	// if (!empty($search_value) && $paged > 1) {
	//     $paged = 1;
	// }
	$args = array(
		'post_type' => 'post',
		'posts_per_page' => 6,
		'paged' => $paged,
		'post_status' => 'publish'
	);

	if (!empty($search_value)) {
		$args['s'] = $search_value;
	}

	if ($cat_id !== 'view-all') {

		$args['tax_query'] = array(
			array(
				'taxonomy' => 'category',
				'field' => 'slug',
				'terms' => $cat_id,
			),
		);
	}
	// echo '<pre>'; print_r( $args ); echo '</pre>';
	$query = new WP_Query($args);
	$response = array(
		'html' => '',
		'current_page' => $paged,
		'total_pages' => $query->max_num_pages,
	);
	// echo '<pre>'; print_r($response);'</pre>';
	if ($query->have_posts()) {
		ob_start(); // Start buffering the HTML output
		while ($query->have_posts()) {
			$query->the_post();
			
			echo common_struture_posts();
		}
		$response['html'] = ob_get_clean(); // Store the buffered content in the response
		wp_reset_postdata();
	} else {
		$response['html'] = '<p>No results found.</p>';

	}
	wp_send_json($response); // Send the JSON response and die

	wp_die();
}

add_action('wp_ajax_nopriv_load_more_case_studies', 'load_more_case_studies');
add_action('wp_ajax_load_more_case_studies', 'load_more_case_studies');

//add this filter for not to scroll top after click on submit , next and previous

add_filter( 'gform_confirmation_anchor', '__return_false', 100 );//hooked late to make sure we have the last say