<?php
/**
 * The template for displaying archive pages
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package Simplify_365
 */

get_header();
// banner_details(get_the_archive_title(), null);

$site_name = get_bloginfo('site_name');
$category_page_content = get_field('category_page_content', 'option');
?>

<main id="primary" class="site-main">
    <!-- Inner Banner Section Start -->
    <section class="inner-banner">
        <div class="container">
            <div class="inner-banner-content-wp">
                <div class="row justify-content-center">
                    <div class="col-lg-10 col-xl-8">
                        <div class="inner-banner-content">
                            <!-- Display the category name dynamically -->
                            <h1 class="h1-title"><?php single_cat_title(); ?> with <?php echo $site_name; ?> ®</h1>
                            <div class="body-l">
                                <?php
                                echo wp_kses_post($category_page_content);
                                ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <!-- Inner Banner Section End -->

    <!-- Case Study Section Start -->
    <section class="case-study-section">
        <div class="container">
            <div class="case-study-content-wp">

                <div class="case-study-filter-tab filter-tabing">
                    <ul>
                        <li class="<?php if (!is_tax('case-studies-category')) {
                            echo 'active';
                        } ?>"
                            data-category-id="view-all">
                            <a href="<?php echo get_post_type_archive_link('case-studies'); ?>">View All</a>
                        </li>
                        <?php
                        $categories = get_terms(array(
                            'taxonomy' => 'case-studies-category',
                            'hide_empty' => true,
                        ));

                        foreach ($categories as $category) {
                            // Get the category link
                            $category_link = get_term_link($category);

                            // Check if the current category is active
                            $active_class = (is_tax('case-studies-category', $category->term_id)) ? 'active' : '';
                            echo '<li class="' . esc_attr($active_class) . '" data-category-id="' . esc_html($category->slug) . '">
                                <a href="' . esc_url($category_link) . '">' . esc_html($category->name) . '</a>
                                </li>';
                        }
                        ?>
                    </ul>
                </div>
                <?php 
                $limit = 6;
                $args = array(
                    'post_type'         => 'case-studies',
                    'post_status'       => 'publish',
                    'posts_per_page'    =>  $limit,
                    'tax_query' =>  array(
                            array(
                                'taxonomy' => 'case-studies-category',
                                'field'    => 'id',
                                'terms'    => get_queried_object()->term_id
                            )
                    )
                
                );                
                // The Query.
                $query = new WP_Query($args);
                // echo '<pre>'; print_r( $the_query ); echo '</pre>';
                if ($query->have_posts()) {
                ?>
                <div class="card-wp">
                    <div class="row" id="posts-container">
                        <?php
                        // Fetch posts for the current category
                            while ($query->have_posts()) {
                                $query->the_post();

                                $categories = get_the_category();
                                $cat_list = [];
                                if (!empty($categories)) {
                                    foreach ($categories as $category) {
                                        $cat_list[] = $category->name;
                                    }
                                }
                                $default_image = home_url() . '/wp-content/uploads/2024/10/placeholder-image.png';
                                $thumbnail_image = !empty(get_the_post_thumbnail_url()) ? esc_url(get_the_post_thumbnail_url()) : $default_image;
                                ?>
                                <div class="col-sm-6 col-lg-4 post-item">
                                    <div class="info-card">
                                        <div class="card-img">
                                            <a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>" class="back-img"
                                                style="background-image: url('<?php echo $thumbnail_image ?>')"></a>
                                            <?php
                                            $video_url = get_field('video_url');
                                            if (!empty($video_url)) {
                                                play_icon($video_url);
                                            }
                                            ?>
                                        </div>
                                        <div class="card-content">
                                            <div class="body-s">
                                                <p class="card-info-tag"><?php echo implode(', ', $cat_list); ?></p>
                                            </div>
                                            <h4 class="h4-title">
                                                <a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>">
                                                    <?php the_title(); ?>
                                                </a>
                                            </h4>
                                            <p><?php echo wp_trim_words(get_the_excerpt(), 20); ?></p>
                                        </div>
                                    </div>
                                </div>
                                <?php
                            }
                         ?>
                    </div>
                    <?php
                    $total_pages = $query->max_num_pages; // Get total number of pages
                    $total_post = $query->found_posts;

                    if ($total_post >  $limit) {
                        ?>
                        <div class="load-more-btn-wp">
                            <button id="load-more" class="load-more sec-btn btn-transparent" data-page="1"
                                data-max-pages="<?php echo $total_pages; ?>" title="Load More">Load More</button>
                        </div>
                        <?php
                    } ?>
                </div>
                <?php 
                wp_reset_postdata();
            } ?>
            </div>
        </div>
    </section>
    <!-- Case Study Section End -->


</main><!-- #main -->

<?php

get_footer();
